@@ -2,31 +2,35 @@ get_objects <- function(type, selection = NULL, sample_prior = F, design = NULL,
                         prior = NULL, stage = 'sample', N = 1e5, ...){
   return_prior <- ifelse(is.null(sampler), TRUE, FALSE)
   if(type == "standard"){
-    out <- get_objects_standard(type, selection, sample_prior, return_prior, design, prior, stage, N = N,
+    out <- get_objects_standard(selection, sample_prior, return_prior, design, prior, stage, N = N,
                                 sampler, ...)
   }
   else if(type == "single"){
-    out <- get_objects_single(type, selection, sample_prior, return_prior, design, prior, stage, N = N,
+    out <- get_objects_single(selection, sample_prior, return_prior, design, prior, stage, N = N,
                                 sampler, ...)
   }
   else if(type == "diagonal"){
-    out <- get_objects_diag(type, selection, sample_prior, return_prior, design, prior, stage, N = N,
+    out <- get_objects_diag(selection, sample_prior, return_prior, design, prior, stage, N = N,
                               sampler, ...)
   }
+  else if(type == "diagonal-gamma"){
+    out <- get_objects_diag_gamma(selection, sample_prior, return_prior, design, prior, stage, N = N,
+                            sampler, ...)
+  }
   else if(type == "blocked"){
-    out <- get_objects_blocked(type, selection, sample_prior, return_prior, design, prior, stage, N = N,
+    out <- get_objects_blocked(selection, sample_prior, return_prior, design, prior, stage, N = N,
                             sampler, ...)
   }
   else if(type == "infnt_factor"){
-    out <- get_objects_infnt_factor(type, selection, sample_prior, return_prior, design, prior, stage, N = N,
+    out <- get_objects_infnt_factor(selection, sample_prior, return_prior, design, prior, stage, N = N,
                                sampler, ...)
   }
   else if(type == "factor"){
-    out <- get_objects_factor(type, selection, sample_prior, return_prior, design, prior, stage, N = N,
+    out <- get_objects_factor(selection, sample_prior, return_prior, design, prior, stage, N = N,
                                     sampler,...)
   }
   else if(type == "SEM"){
-    out <- get_objects_SEM(type, selection, sample_prior, return_prior, design, prior, stage, N = N,
+    out <- get_objects_SEM(selection, sample_prior, return_prior, design, prior, stage, N = N,
                               sampler,...)
   }
   else{
@@ -54,25 +58,26 @@ add_prior_names <- function(prior, design){
   return(prior)
 }
 
-get_objects_diag <- function(type, selection, sample_prior, return_prior, design = NULL,
+get_objects_diag <- function(selection, sample_prior, return_prior, design = NULL,
                                  prior = NULL, stage = 'sample', N = 1e5, sampler = NULL,...){
   acc_selection <- c("mu", "sigma2", "alpha", "LL", "Sigma")
   if(return_prior & !sample_prior){
-    prior$prior <- get_prior_diag(design = design, sample = F, prior = prior)
+    if(is.null(list(...)$return_info)) prior$prior <- get_prior_diag(design = design, sample = F, prior = prior)
     prior$descriptions <- list(
       theta_mu_mean = "mean of the group-level mean prior",
       theta_mu_var = "variance of the group-level mean prior",
       v = "degrees of freedom on the group-level variance prior",
       A = "scale on the group-level variance prior, larger values lead to larger variances"
     )
-    prior$groups <- list(
+    prior$types <- list(
       mu = c("theta_mu_mean", "theta_mu_var"),
       Sigma = c("v", "A")
     )
-    prior$group_descriptions <- list(
+    prior$type_descriptions <- list(
       mu = "Group-level mean",
       Sigma = 'Group-level covariance matrix'
     )
+    if(!is.null(list(...)$return_info))return(prior)
     prior$prior <- add_prior_names(prior$prior, design)
     return(prior)
   } else{
@@ -94,26 +99,68 @@ get_objects_diag <- function(type, selection, sample_prior, return_prior, design
   }
 }
 
+get_objects_diag_gamma <- function(selection, sample_prior, return_prior, design = NULL,
+                             prior = NULL, stage = 'sample', N = 1e5, sampler = NULL,...){
+  acc_selection <- c("mu", "sigma2", "alpha", "LL", "Sigma")
+  if(return_prior & !sample_prior){
+    if(is.null(list(...)$return_info)) prior$prior <- get_prior_diag_gamma(design = design, sample = F, prior = prior)
+    prior$descriptions <- list(
+      theta_mu_mean = "mean of the group-level mean prior",
+      theta_mu_var = "variance of the group-level mean prior",
+      shape = "shape of the group-level variance prior",
+      rate = "rate of the group-level variance prior"
+    )
+    prior$types <- list(
+      mu = c("theta_mu_mean", "theta_mu_var"),
+      Sigma = c("shape", "rate")
+    )
+    prior$type_descriptions <- list(
+      mu = "Group-level mean",
+      Sigma = 'Group-level covariance matrix'
+    )
+    if(!is.null(list(...)$return_info)) return(prior[c("types", "type_descriptions", "descriptions")])
+    prior$prior <- add_prior_names(prior$prior, design)
+    return(prior)
+  } else{
+    if(!selection %in% acc_selection) stop(paste0("selection must be in : ", paste(acc_selection, collapse = ", ")))
+    if(sample_prior){
+      if(selection == "alpha" & !is.null(sampler)){
+        mu <- get_pars(sampler, selection = "mu", stage = stage, map = FALSE, return_mcmc = FALSE, merge_chains = TRUE, ...)
+        var <- get_pars(sampler, selection = "Sigma", stage = stage, map = FALSE, return_mcmc = FALSE, merge_chains = TRUE, ...)
+        sub_names <- names(sampler[[1]]$data)
+        sampler <- list(list(samples =  list(alpha = get_alphas(mu, var, sub_names))))
+      } else{
+        sampler <- list(list(samples = get_prior_diag_gamma(prior = prior, design = design, selection = selection,N = N)))
+      }
+      attr(sampler, "design_list") <- list(design)
+      return(sampler)
+    }
+    idx <- get_idx(sampler, stage)
+    return(get_base(sampler, idx, selection))
+  }
+}
 
-get_objects_standard <- function(type, selection, sample_prior, return_prior, design = NULL,
+
+get_objects_standard <- function(selection, sample_prior, return_prior, design = NULL,
                                  prior = NULL, stage = 'sample', N = 1e5, sampler = NULL, ...){
   acc_selection <- c("mu", "sigma2", "covariance", "correlation", "alpha", "Sigma", "LL")
   if(return_prior & !sample_prior){
-    prior$prior <- get_prior_standard(design = design, sample = F, prior = prior)
+    if(is.null(list(...)$return_info)) prior$prior <- get_prior_standard(design = design, sample = F, prior = prior)
     prior$descriptions <- list(
       theta_mu_mean = "mean of the group-level mean prior",
       theta_mu_var = "variance of the group-level mean prior",
       v = "degrees of freedom on the group-level (co-)variance prior, 2 leads to uniform correlations. Single value",
       A = "scale on the group-level variance prior, larger values lead to larger variances"
     )
-    prior$groups <- list(
+    prior$types <- list(
       mu = c("theta_mu_mean", "theta_mu_var"),
       Sigma = c("v", "A")
     )
-    prior$group_descriptions <- list(
+    prior$type_descriptions <- list(
       mu = "Group-level mean",
       Sigma = 'Group-level covariance matrix'
     )
+    if(!is.null(list(...)$return_info)) return(prior[c("types", "type_descriptions", "descriptions")])
     prior$prior <- add_prior_names(prior$prior, design)
     return(prior)
   } else{
@@ -148,25 +195,26 @@ get_idx <- function(sampler, stage){
 
 
 
-get_objects_blocked <- function(type, selection, sample_prior, return_prior, design = NULL,
+get_objects_blocked <- function(selection, sample_prior, return_prior, design = NULL,
                                  prior = NULL, stage = 'sample', N = 1e5, sampler = NULL,...){
   acc_selection <- c("mu", "sigma2", "covariance", "correlation", "alpha", "Sigma", "LL")
   if(return_prior & !sample_prior){
-    prior$prior <- do.call(get_prior_blocked, c(list(design = design, sample = F, prior = prior), fix_dots(list(...), get_prior_blocked)))
+    if(is.null(list(...)$return_info)) prior$prior <- do.call(get_prior_blocked, c(list(design = design, sample = F, prior = prior), fix_dots(list(...), get_prior_blocked)))
     prior$descriptions <- list(
       theta_mu_mean = "mean of the group-level mean prior",
       theta_mu_var = "variance of the group-level mean prior",
       v = "degrees of freedom on the group-level (co-)variance prior, 2 leads to uniform correlations. Single value",
       A = "scale on the group-level variance prior, larger values lead to larger variances"
     )
-    prior$groups <- list(
+    prior$types <- list(
       mu = c("theta_mu_mean", "theta_mu_var"),
       Sigma = c("v", "A")
     )
-    prior$group_descriptions <- list(
+    prior$type_descriptions <- list(
       mu = "Group-level mean",
       Sigma = 'Group-level covariance matrix'
     )
+    if(!is.null(list(...)$return_info)) return(prior[c("types", "type_descriptions", "descriptions")])
     prior$prior <- add_prior_names(prior$prior, design)
     return(prior)
   } else{
@@ -196,21 +244,22 @@ get_objects_blocked <- function(type, selection, sample_prior, return_prior, des
 
 
 
-get_objects_single <- function(type, selection, sample_prior, return_prior, design = NULL,
+get_objects_single <- function(selection, sample_prior, return_prior, design = NULL,
                                  prior = NULL, stage = 'sample', N = 1e5, sampler = NULL,...){
   acc_selection <- c("alpha", "LL")
   if(return_prior & !sample_prior){
-    prior$prior <- get_prior_single(design = design, sample = F, prior = prior)
+    if(is.null(list(...)$return_info)) prior$prior <- get_prior_single(design = design, sample = F, prior = prior)
     prior$descriptions <- list(
       theta_mu_mean = "mean of the prior",
       theta_mu_var = "variance of the prior"
     )
-    prior$groups <- list(
+    prior$types <- list(
       alpha = c("theta_mu_mean", "theta_mu_var")
     )
-    prior$group_descriptions <- list(
+    prior$type_descriptions <- list(
       alpha = "Subject-level prior"
     )
+    if(!is.null(list(...)$return_info)) return(prior[c("types", "type_descriptions", "descriptions")])
     prior$prior <- add_prior_names(prior$prior, design)
     return(prior)
   } else{
@@ -225,11 +274,11 @@ get_objects_single <- function(type, selection, sample_prior, return_prior, desi
   }
 }
 
-get_objects_factor <- function(type, selection, sample_prior, return_prior, design = NULL,
+get_objects_factor <- function(selection, sample_prior, return_prior, design = NULL,
                                      prior = NULL, stage = 'sample', N = 1e5, sampler = NULL, ...){
   acc_selection <- c("mu", "sigma2", "covariance", "correlation", "alpha", "Sigma", "loadings", "residuals", "LL")
   if(return_prior & !sample_prior){
-    prior$prior <- do.call(get_prior_factor, c(list(design = design, sample = F, prior = prior), fix_dots(list(...), get_prior_factor)))
+    if(is.null(list(...)$return_info)) prior$prior <- do.call(get_prior_factor, c(list(design = design, sample = F, prior = prior), fix_dots(list(...), get_prior_factor)))
     prior$descriptions <- list(
       theta_mu_mean = "mean of the group-level mean prior",
       theta_mu_var = "variance of the group-level mean prior",
@@ -239,16 +288,17 @@ get_objects_factor <- function(type, selection, sample_prior, return_prior, desi
       ap = "shape prior of inverse gamma on factor variances",
       bp = "rate prior of inverse gamma on factor variances"
     )
-    prior$groups <- list(
+    prior$types <- list(
       mu = c("theta_mu_mean", "theta_mu_var"),
       loadings = c("theta_lambda_var", "ap", "bp"),
       residuals = c("as", "bs")
     )
-    prior$group_descriptions <- list(
+    prior$type_descriptions <- list(
       mu = "Group-level mean",
       loadings = "Factor loadings",
       residuals = "Residual errors on the variances"
     )
+    if(!is.null(list(...)$return_info)) return(prior[c("types", "type_descriptions", "descriptions")])
     prior$prior <- add_prior_names(prior$prior, design)
     return(prior)
   } else{
@@ -276,7 +326,7 @@ get_objects_factor <- function(type, selection, sample_prior, return_prior, desi
       return(lapply(sampler, FUN = function(x) return(x$samples$theta_lambda[,,idx])))
     }
     if(selection == "residuals"){
-      return(lapply(sampler, FUN = function(x) return(1/x$samples$sig_err_inv[,idx])))
+      return(lapply(sampler, FUN = function(x) return(1/x$samples$theta_sig_err_inv[,idx])))
     }
     return(get_base(sampler, idx, selection))
   }
@@ -284,32 +334,33 @@ get_objects_factor <- function(type, selection, sample_prior, return_prior, desi
 
 
 
-get_objects_infnt_factor <- function(type, selection, sample_prior, return_prior, design = NULL,
+get_objects_infnt_factor <- function(selection, sample_prior, return_prior, design = NULL,
                                  prior = NULL, stage = 'sample', N = 1e5, sampler = NULL, ...){
   acc_selection <- c("mu", "sigma2", "covariance", "correlation", "alpha", "Sigma", "loadings", "residuals", "LL")
   if(return_prior & !sample_prior){
-    prior$prior <- do.call(get_prior_infnt_factor, c(list(design = design, sample = F, prior = prior), fix_dots(list(...), get_prior_infnt_factor)))
+    if(is.null(list(...)$return_info)) prior$prior <- do.call(get_prior_infnt_factor, c(list(design = design, sample = F, prior = prior), fix_dots(list(...), get_prior_infnt_factor)))
     prior$descriptions <- list(
       theta_mu_mean = "mean of the group-level mean prior",
       theta_mu_var = "variance of the group-level mean prior",
       as = "shape of inverse-gamma prior on the residual variances",
       bs = "rate of inverse-gamma prior on the residual variances",
-      df = "shape and rate prior on cross-loadings (local) shrinkage parameter",
+      df = "shape and rate prior on loadings (local) shrinkage parameter",
       ad1 = "shape prior on factor loading variances of first column",
       bd1 = "rate prior on factor loading variances of first column",
       ad2 = "multiplicative shape prior on factor loading variances of subsequent columns",
       bd2 = "multiplicative rate prior on factor loading variances of subsequent columns"
     )
-    prior$groups <- list(
+    prior$types <- list(
       mu = c("theta_mu_mean", "theta_mu_var"),
       loadings = c("df", "ad1", "bd1",  "ad2", "bd2"),
       residuals = c("as", "bs")
     )
-    prior$group_descriptions <- list(
+    prior$type_descriptions <- list(
       mu = "Group-level mean",
       loadings = "Factor loadings",
       residuals = "Residual errors on the variances"
     )
+    if(!is.null(list(...)$return_info)) return(prior[c("types", "type_descriptions", "descriptions")])
     prior$prior <- add_prior_names(prior$prior, design)
     return(prior)
   } else{
@@ -333,20 +384,20 @@ get_objects_infnt_factor <- function(type, selection, sample_prior, return_prior
       return(lapply(sampler, FUN = function(x) return(x$samples$theta_lambda[,,idx])))
     }
     if(selection == "residuals"){
-      return(lapply(sampler, FUN = function(x) return(1/x$samples$sig_err_inv[,idx])))
+      return(lapply(sampler, FUN = function(x) return(1/x$samples$theta_sig_err_inv[,idx])))
     }
     return(get_base(sampler, idx, selection))
   }
 }
 
 
-get_objects_SEM <- function(type, selection, sample_prior, return_prior, design = NULL,
+get_objects_SEM <- function(selection, sample_prior, return_prior, design = NULL,
                                prior = NULL, stage = 'sample', N = 1e5, sampler = NULL, ...){
   acc_selection <- c("mu", "sigma2", "covariance", "alpha", "correlation", "Sigma", "loadings", "residuals",
                      "factor_residuals", "regressors", "factor_regressors", "structural_regressors",
                      "mu_implied", "LL")
   if(return_prior & !sample_prior){
-    prior$prior <- do.call(get_prior_SEM, c(list(design = design, sample = F, prior = prior), fix_dots(list(...), get_prior_SEM)))
+    if(is.null(list(...)$return_info)) prior$prior <- do.call(get_prior_SEM, c(list(design = design, sample = F, prior = prior), fix_dots(list(...), get_prior_SEM)))
     prior$descriptions <- list(
       theta_mu_mean = "mean of the group-level mean prior",
       theta_mu_var = "variance of the group-level mean prior",
@@ -359,7 +410,7 @@ get_objects_SEM <- function(type, selection, sample_prior, return_prior, design
       a_e = "shape prior of inverse gamma on residuals",
       b_e = "rate prior of inverse gamma on residuals"
     )
-    prior$groups <- list(
+    prior$types <- list(
       mu = c("theta_mu_mean", "theta_mu_var"),
       loadings = c("theta_lambda_var"),
       residuals = c("a_e", "b_e"),
@@ -368,7 +419,7 @@ get_objects_SEM <- function(type, selection, sample_prior, return_prior, design
       factor_regressors = c("G_var"),
       structural_regressors = c("B_var")
     )
-    prior$group_descriptions <- list(
+    prior$type_descriptions <- list(
       mu = "group-level mean",
       loadings = "factor variances",
       residuals = "residuals on parameter variances",
@@ -377,6 +428,7 @@ get_objects_SEM <- function(type, selection, sample_prior, return_prior, design
       factor_regressors = "regressors on factors",
       structural_regressors = "structural regressors between factors"
     )
+    if(!is.null(list(...)$return_info)) return(prior[c("types", "type_descriptions", "descriptions")])
     prior$prior <- add_prior_names(prior$prior, design)
     return(prior)
   } else{
@@ -439,24 +491,6 @@ get_objects_SEM <- function(type, selection, sample_prior, return_prior, design
   }
 }
 
-get_mu_implied <- function(x, idx){
-  mu <- x$samples$theta_mu[,idx]
-  B <- x$samples$B[,,idx, drop = F]
-  G <- x$samples$G[,,idx, drop = F]
-  K <- x$samples$K[,,idx, drop = F]
-  loadings <- x$samples$lambda[,,idx, drop = F]
-  n_factors <- ncol(loadings)
-  x_mu <- colMeans(x$covariates)
-  for(i in 1:ncol(mu)){
-    B_0_inv <- solve(diag(n_factors) - as.matrix(B[,,i]))
-    mu[,i] <- as.matrix(mu[,i]) + as.matrix(loadings[,,i]) %*% B_0_inv %*% as.matrix(G[,,i]) %*% x_mu
-                + as.matrix(K[,,i]) %*% x_mu
-  }
-  return(mu)
-}
-
-
-
 get_base <- function(sampler, idx, selection){
   if(selection == "alpha"){
     return(lapply(sampler, FUN = function(x) return(x$samples$alpha[,,idx, drop = F])))
